/*		 ITI-FG  Kernel module free public release
 *
 *		     Copyright (C) 1996-2000 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: icpciReg.h,v 7.0 2000/10/25 09:07:57 cvs Exp $
 *
 */

#ifndef _ICPCIREG_H
#define _ICPCIREG_H

#if defined(linux) && defined(__KERNEL__) || \
    defined(__NetBSD__) && defined(_KERNEL) || \
    !defined(OS_DEFINED) || defined(__CONFIG__)

/* IC-PCI Hardware Reference Manual; Imaging Technology Inc. */
/* Document Number 47-H600002-0[0|1]; March 1995, revised March 1998 */

/* R-O   Read-Only Register */
/* W-O   Write-Only Register */
/* R/W   Read/Write Register */
/* R/W1C Clear on Write One to Register */
/* R/W0C Clear on Write Zero to Register */

/* IC-PCI Control Registers (16bit access only), pages 3-25 to 3-40 */
/* access via memory mapped registers **OR** special i/o operations */
/* **************************************************************** */

#ifdef __cplusplus
extern "C" {
#endif

#define ICP_REV_A		0x03	/* first board layout till # */
#define ICP_REV_B		0x04	/* second board layout from # */
					/* 24bit acquisition AND storage */
					/* write zoom (hardware decimation) */
					/* clipping 0x00-0x0F/0xF0-0cFF */
					/* 8bit parallel i/o ports with
					   strobe and interrupts */

#define CR_DISABLE		0
#define CR_ENABLE		1

#define	ICP_CR_REG_SIZE		(19 * sizeof(u_short))

#define CR_NO_MASK		0xFFFF		/* no range checking */
#define CR_NO_MIN		0x0000
#define CR_NO_MAX		0xFFFF

/*    u_short      con;		Control */
/*--------------------------------------*/

#define CR_CON_OFFSET		0x00
#define CR_CON_INIT		0x0000
				/* Bus Master Disable */
				/* De-Interlacing Disabled */
				/* Camera Pixel Size 1 to 8 bits*/
				/* 2Mb Frame Grabber Memory */

/*    u_short	bmstren:1;	Bus Master Memory Access R/W */

#define CR_BMSTREN_MASK 	0x0001
#define CR_BMSTREN_SHIFT 	0

/*    u_short	bmilace:1;	Bus Master Interlaced Images R/W */

#define CR_BMILACE_MASK		0x0002
#define CR_BMILACE_SHIFT	1

/*    u_short	pixsz:2;	Camera Pixel Size R/W */

#define CR_PIXSZ_MASK		0x000C
#define CR_PIXSZ_SHIFT		2
#define CR_PIXSZ_8		0	/* Camera Pixel Size  1 to  8 bit */
#define CR_PIXSZ_16		1	/* Camera Pixel Size  9 to 16 bit */
#define CR_PIXSZ_24_32		2	/* Camera Pixel Size 17 to 24 bit */
					/* one pixel is stored in 32 bit */
#define CR_PIXSZ_24_24		3	/* Camera Pixel Size 17 to 24 bit */
					/* one pixel is stored in 24 bit */
					/* REV-B Only! */

/*    u_short	memcfg:1;	Memory Configuration R/W */

#define CR_MEMCFG_MASK		0x0010
#define CR_MEMCFG_SHIFT		4
#define CR_MEM_2		0	/* 2 MByte Frame Buffer Memory */
#define CR_MEM_4		1	/* 4 MByte Frame Buffer Memory */

/*    u_short	vbstat:1;	Camera Vertical Blank Status R-O */

#define CR_VBSTAT_MASK		0x0020
#define CR_VBSTAT_SHIFT		5
#define CR_IN_VB		0	/* Camera in Vertical Blank */
#define CR_OUT_VB		1	/* Camera not in Vertical Blank */

/*    u_short	fldstat:1;	Camera Field Status R-O */

#define CR_FLDSTAT_MASK 	0x0040
#define CR_FLDSTAT_SHIFT	6
#define CR_IN_EVEN_FIELD	0	/* Camera in Even Field */
#define CR_IN_ODD_FIELD		1	/* Camera in Odd Field */

/*    u_short	smstat:1;	Camera Scan Mode Status R-O */

#define CR_SMSTAT_MASK  	0x0080
#define CR_SMSTAT_SHIFT		7
#define CR_NON_ILACE		0	/* Non-Interlaced Video */
#define CR_ILACE		1	/* Interlaced Video */

/*    u_short	amp:1;		Acquisition Module Present R-O */

#define CR_AMP_MASK		0x0100
#define CR_AMP_SHIFT		8
#define CR_AM_PESENT		0	/* Acquisition Module installed */
#define CR_AM_ABSENT		1	/* No Acquisition Module present */

/*    u_short	res_1:7;	reserved - reset to 0 */

/*    u_short	acqcon;		Acquire Control */
/*----------------------------------------------*/

#define CR_ACQCON_OFFSET	0x02

#define CR_ACQCON_INIT		0x0080
				/* Trigger Disabled */
				/* Acquire 1 frame */
				/* Start Acquire at Even Field */
				/* Freeze */

/*    u_short	tmode:1;	Trigger Mode Acquisition R/W */

#define CR_TMODE_MASK		0x0001
#define CR_TMODE_SHIFT		0

/*    u_short	fcnt:3;		Snap Frame Count R/W */

#define CR_FCNT_MASK		0x000E
#define CR_FCNT_SHIFT		1
#define CR_FCNT_MIN		CR_NO_MIN
#define CR_FCNT_MAX		CR_FCNT_MASK >> CR_FCNT_SHIFT

/*    u_short	res_1:2;	reserved - reset to 0 */

/*    u_short	fldsel:2;	Starting Field Select R/W */

#define CR_FLDSEL_MASK		0x00C0
#define CR_FLDSEL_SHIFT		6
#define CR_NEXT_FIELD		0	/* Start Acquisition at Next Field */
#define CR_EVEN_FIELD		2	/* Start Acquisition at Even Field */
#define CR_ODD_FIELD		3	/* Start Acquisition at Odd Field */

/*    u_short	acqmd:2;	Acquisition Mode R/W */

#define CR_ACQMD_MASK		0x0300
#define CR_ACQMD_SHIFT		8
#define CR_FREEZE		0	/* Freeze */
#define CR_SNAP			2	/* Snap */
#define CR_GRAB			3	/* Grab */

/*    u_short	newaq:1;	New Acquire R-O */ 

#define CR_NEWAQ_MASK		0x0400
#define CR_NEWAQ_SHIFT		10

/*    u_short	gstat:1;	GRAB Status R-O */

#define CR_GSTAT_MASK		0x0800
#define CR_GSTAT_SHIFT		11

/*    u_short	fstrt:1;	Field Start Status R-O */
/*    u_short	res_2:3;	reserved - reset to 0 */

#define CR_FSTRT_MASK		0x1000
#define CR_FSTRT_SHIFT		12
#define CR_FIELD_EVEN		0	/* I-laced Video start on even field */
#define CR_FIELD_ODD		1	/* I-laced Video start on odd field */

/*    u_short	pitch;		Image Pitch = n * pixel per line / 8 */
/*                              n = 1-8bit/ 2-16bit/ 4-24bit) */
/*                              0:11 -> 3:14 R/W */

#define CR_PITCH_OFFSET		0x04
#define CR_PITCH_MASK		0x0FFF
#define CR_PITCH_SHIFT		3
#define CR_PITCH_MIN		1
#define CR_PITCH_MAX		CR_PITCH_MASK
#define CR_PITCH_INIT		8 /* 8 pixels per line (8bit) */

/*    u_short	aoix;		Area Of Interest Horizontal Dimension */
/*				= n * pixel per line / 8 */
/*                              n = 1-8bit/ 2-16bit/ 4-24bit) */
/*                              0:11 -> 3:14 R/W */

#define CR_AOIX_OFFSET		0x06
#define CR_AOIX_MASK		CR_PITCH_MASK
#define CR_AOIX_SHIFT		CR_PITCH_SHIFT
#define CR_AOIX_MIN		CR_PITCH_MIN
#define CR_AOIX_MAX		CR_PITCH_MAX
#define CR_AOIX_INIT		CR_PITCH_INIT

/*    u_short	bmsfl;		Bus Master First Field Start Address */
/*				Low 0:9 -> 3:12 R/W */

#define CR_BMSFL_OFFSET		0x08
#define CR_BMSFL_MASK		0x03FF
#define CR_BMSFL_SHIFT		3
#define CR_BMSFL_MIN		CR_NO_MIN
#define CR_BMSFL_MAX		CR_BMSFL_MASK

/*    u_short	bmsfh;		Bus Master First Field Start Address */
/*				High 0:8 -> 13:21(4Mb) 13:20(2Mb) R/W */

#define CR_BMSFH_OFFSET		0x0A
#define CR_BMSFH_MASK 		0x00FF
#define CR_BMSFH_SHIFT		13
#define CR_BMSFH_MIN		CR_NO_MIN
#define CR_BMSFH_MAX		CR_BMSFH_MASK
#define CR_BMSF_INIT		0x0000

/*    u_short	bmssl;		Bus Master Second Field Start Address */
/*				Low 0:9 -> 3:12 R/W */

#define CR_BMSSL_OFFSET		0x0C
#define CR_BMSSL_MASK		CR_BMSFL_MASK
#define CR_BMSSL_SHIFT		CR_BMSFL_SHIFT
#define CR_BMSSL_MIN		CR_BMSFL_MIN
#define CR_BMSSL_MAX		CR_BMSFL_MAX

/*    u_short	bmssh;		Bus Master Second Field Start Address */
/*				High 0:8 -> 13:21(4Mb) 13:20(2Mb) R/W */

#define CR_BMSSH_OFFSET		0x0E
#define CR_BMSSH_MASK		CR_BMSFH_MASK
#define CR_BMSSH_SHIFT		CR_BMSFH_SHIFT
#define CR_BMSSH_MIN		CR_BMSFH_MIN
#define CR_BMSSH_MAX		CR_BMSFH_MAX
#define CR_BMSS_INIT		CR_BMSF_INIT

/*    u_short	aqstart		Acquisition Start Address */
/*                              0:9 -> 12-21(4Mb) 12-20(2Mb) R/W */

#define CR_AQSTART_OFFSET	0x10
#define CR_AQSTART_MASK		0x01FF
#define CR_AQSTART_SHIFT	12
#define CR_AQSTART_MIN		CR_NO_MIN
#define CR_AQSTART_MAX		CR_AQSTART_MASK
#define CR_AQSTART_INIT		0x0000

/*    u_short	aqadr;		Acquisition Address Status */
/*                              0:9 -> 12-21(4Mb) 12-20(2Mb) R-O */

#define CR_AQADR_OFFSET		0x12
#define CR_AQADR_MASK		CR_AQSTART_MASK
#define CR_AQADR_SHIFT		12
#define CR_AQADR_MIN		CR_NO_MIN
#define CR_AQADR_MAX		CR_AQADR_MASK

/*    u_short	intadr;		Acquisition Address Interrupt */
/*                              0:5 -> 16-21(4Mb) 16-20(2Mb) R/W */

#define CR_INTADR_OFFSET	0x14
#define CR_INTADR_MASK		0x003F
#define CR_INTADR_SHIFT		16
#define CR_INTADR_MIN		CR_NO_MIN
#define CR_INTADR_MAX		CR_INTADR_MASK
#define CR_INTADR_INIT		0x0000

/*    u_short	intcon;		Interrupt Control */
/* -----------------------------------------------*/

#define CR_INTCON_OFFSET	0x16
#define CR_INTCON_INIT		0x0000
				/* No Interrupt Enabled */
				/* Clear All Interrupts R/W0C */

#define CR_IRQ_TEST_MASK	0x3F80	/* here are intr. status bits
					   see xcr_test/clear_irq */

/*    u_short	vbien:1;	Vertikal Blank Interrupt R/W0C*/

#define CR_VBIEN_MASK		0x0001
#define CR_VBIEN_SHIFT		0

/*    u_short	ovbien:1;	Odd Vertikal Blank Interrupt R/W0C */

#define CR_OVBIEN_MASK		0x0002
#define CR_OVBIEN_SHIFT		1

/*    u_short	evbien:1;	Even Vertikal Blank Interrupt R/W0C */

#define CR_EVBIEN_MASK		0x0004
#define CR_EVBIEN_SHIFT		2

/*    u_short	amien:1;	AM Interrupt R/W0C */

#define CR_AMIEN_MASK		0x0008
#define CR_AMIEN_SHIFT		3

/*    u_short	trigien:1;	External Trigger Interrupt R/W0C */

#define CR_TRIGIEN_MASK		0x0010
#define CR_TRIGIEN_SHIFT	4

/*    u_short	adrien:1;	Acquire Address Interrupt R/W0C */

#define CR_ADRIEN_MASK		0x0020
#define CR_ADRIEN_SHIFT		5

/*    u_short	aqien:1;	Acquire Interrupt R/W0C */

#define CR_AQIEN_MASK		0x0040
#define CR_AQIEN_SHIFT		6

/*    u_short	vbint:1;	Vertikal Blank Interrupt Status R-O */

#define CR_VBINT_MASK		0x0080
#define CR_VBINT_SHIFT		7

/*    u_short	ovbint:1;	Odd Vertikal Blank Interrupt Status R-O */

#define CR_OVBINT_MASK		0x0100
#define CR_OVBINT_SHIFT		8

/*    u_short	evbint:1;	Even Vertikal Blank Interrupt Status R-O */

#define CR_EVBINT_MASK		0x0200
#define CR_EVBINT_SHIFT		9

/*    u_short	amint:1;	AM Interrupt Status R-O */

#define CR_AMINT_MASK		0x0400
#define CR_AMINT_SHIFT		10

/*    u_short	trigint:1;	External Trigger Interrupt Status R-O */

#define CR_TRIGINT_MASK		0x0800
#define CR_TRIGINT_SHIFT	11

/*    u_short	adrint:1;	Acquisition Address Interrupt Status R-O */

#define CR_ADRINT_MASK		0x1000
#define CR_ADRINT_SHIFT		12

/*    u_short	aqint:1;	Acquisition Interrupt Status R-O */

#define CR_AQINT_MASK		0x2000
#define CR_AQINT_SHIFT		13

/*    u_short	res_1:2;	reserved -reset to 0 */

/*    u_short	wzoom;		Write Zoom Control (REV-B Only!) */
/* ------------------------------------------------------------*/

#define CR_WZOOM_OFFSET		0x18
#define CR_WZOOM_INIT		0x0000
				/* No Horizontal or Vertical Decimation */
				/* No Clipping */
				/* No Bus Master Zoom Mode (PCVision Only!) */

/*    u_short	hdec:2;		Horizontal Decimation R/W (REV-B Only!) */

#define CR_HDEC_MASK		0x0003
#define CR_HDEC_SHIFT		0

#define CR_DEC_BY_1		0	/* no decimation (original image) */
#define CR_DEC_BY_2		1	/* a half of the width/height */
#define CR_DEC_BY_4		2	/* a quarter of the width/height */
#define CR_DEC_BY_8		3	/* 1/8 of the width/height */
#define CR_DEC_BY_16		4	/* 1/16 of the width/height */

/*    u_short	vdec:2;		Vertical Decimation R/W (REV-B Only!) */

#define CR_VDEC_MASK		0x000C
#define CR_VDEC_SHIFT		2

/* for values see hdec bits above */

/*    u_short	clip:1;		Bus Master Clipping Enable (REV-B Only!) */

#define CR_CLIP_MASK		0x0010
#define CR_CLIP_SHIFT		4

/*    u_short	res_1:2;	reserved -reset to 0 */

/*    u_short	bmzoom:1;	Bus Master Zoom Mode (PCVision Only!) */

#define CR_BMZOOM_MASK		0x0080
#define CR_BMZOOM_SHIFT		7

/*    u_short	res_2:8;	reserved -reset to 0 */

/*    u_short	mdata;		Mask Data */
/*                              0:15 set to 1 W-O */

#define CR_MDATA_OFFSET		0x1A
#define CR_MDATA_INIT		0xFFFF

/*    u_short	portcon;	Port Control (REV-B Only!) */
/* --------------------------------------------------------*/

#define CR_PORTCON_OFFSET	0x20
#define CR_PORTCON_INIT		0x002D
				/* Strobe Pin Driven High */
				/* Disable Input Buffer and Strobe */
				/* Falling Edge Clocks Data into Buffer */
				/* Input Buffer Cleared */
				/* Input Port Interrupt Disabled */
				/* Input Port Interrupt at Falling Edge */
				/* No Padding (PCVision Only!) */

/*    u_short	outstrb:1;	Output Port Strobe R/W (REV-B Only!) */

#define CR_OUTSTRB_MASK		0x0001
#define CR_OUTSTRB_SHIFT		0

/*    u_short	inregenb:1;	Input Buffer Enable R/W (REV-B Only!) */

#define CR_INREGENB_MASK	0x0002
#define CR_INREGENB_SHIFT	1

/*    u_short	instrbpol:1;	Input Port Strobe Polarity R/W (REV-B Only!) */

#define CR_INSTRBPOL_MASK	0x0004
#define CR_INSTRBPOL_SHIFT	2
#define CR_INSTRB_ACT_HIGH	0	/* Rising Edge Clocks Date into Buf */
#define CR_INSTRB_ACT_LOW	1	/* Falling Edge Clocks Date into Buf */

/*    u_short	inregclr:1;	Input Buffer Clear R/W (REV-B Only!) */

#define CR_INREGCLR_MASK	0x0008
#define CR_INREGCLR_SHIFT	3

/*    u_short	inpien:1;	Input Port Intr. Enable R/W0C (REV-B Only!) */

#define CR_INPIEN_MASK		0x0010
#define CR_INPIEN_SHIFT		4

/*    u_short	inpintpol:1;	Input Port Intr. Polarity R/W (REV-B Only!) */

#define CR_INPINTPOL_MASK	0x0020
#define CR_INPINTPOL_SHIFT	5
#define CR_INPINT_ACT_HIGH	0	/* Rising Edge causes an Interrupt */
#define CR_INPINT_ACT_LOW	1	/* Falling Edge causes an Interrupt */

/*    u_short	inpint:1;	Input Port Intr. Status R-O (REV-B Only!) */

#define CR_INPINT_MASK		0x0040
#define CR_INPINT_SHIFT		6

/*    u_short	res_1:1;	reserved -reset to 0 */

/*    u_short	inprint:1;	Input Port Intr. Pin R-O (REV-B Only!) */

#define CR_INPRINT_MASK		0x0100
#define CR_INPRINT_SHIFT	8

/*    u_short	inprstrb:1;	Input Port Strobe Pin R-O (REV-B Only!) */

#define CR_INPRSTRB_MASK	0x0200
#define CR_INPRSTRB_SHIFT	9

/*    u_short	res_2:2;	reserved -reset to 0 */

/*    u_short	pad16:1;	16bit Padding Enable R/W (PCVision Only!)*/

#define CR_PAD16_MASK		0x1000
#define CR_PAD16_SHIFT		12

/*    u_short	res_3:3;	reserved -reset to 0 */

/*    u_short	outport;	Output Port R/W (REV-B Only!) */
/*                              0:7 -> 8bit Out */

#define CR_OUTPORT_OFFSET	0x22
#define CR_OUTPORT_MASK		0x00FF
#define CR_OUTPORT_SHIFT	0
#define CR_OUTPORT_MIN		CR_NO_MIN
#define CR_OUTPORT_MAX		CR_OUTPORT_MASK
#define CR_OUTPORT_INIT		0x0000

/*    u_short	inport;		Input Port R/W (REV-B Only!) */
/*                              0:7 -> 8bit In */

#define CR_INPORT_OFFSET	0x24
#define CR_INPORT_MASK		0x00FF
#define CR_INPORT_SHIFT		0
#define CR_INPORT_MIN		CR_NO_MIN
#define CR_INPORT_MAX		CR_INPORT_MASK
#define CR_INPORT_INIT		0x0000

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* linux && __KERNEL__ || !OS_DEFINED */

#endif /* _ICPCIREG_H */

